@@ -220,6 +220,9 @@ extern0 SEXP0
     AssignSymbol                           INI_as(Rf_install("<-")),
     ifnotfoundSymbol                       INI_as(Rf_install("ifnotfound")),
 
+    _utf8localeSymbol                      INI_as(Rf_install(".utf8locale")),
+    _latin1localeSymbol                    INI_as(Rf_install(".latin1locale")),
+
     withVisibleSymbol                      INI_as(Rf_install("withVisible"));
 
 
