@@ -2,7 +2,7 @@
 #define R_THISPATH_TRANSLATIONS_H
 
 
-#ifdef ENABLE_NLS
+#if defined(ENABLE_NLS)
 #include <libintl.h>
 #define _(String) dgettext ("R", String)
 #define dgettext_RGui(String) dgettext ("RGui", String)
